aux_info_gen

Function aux_info_gen 

pub fn aux_info_gen<L>(
    eid: ExecutionId<'_>,
    i: u16,
    n: u16,
    pregenerated: PregeneratedPrimes<L>,
) -> AuxInfoBuilder<'_, L>
where L: SecurityLevel,
Protocol for finalizing the keygen by generating aux info.

PregeneratedPrimes can be obtained with key_refresh::PregeneratedPrimes::generate

Index i of party should be the same as index inside the key share you are going to use this aux info with. Number of parties n should be the same as number of signers sharing the key.

Outputs AuxInfo that can be used to “complete” IncompleteKeyShare using KeyShare::from_parts.